@@ -898,8 +898,9 @@ def main_cli():
     # Run in appropriate mode
     if args.port:
         logger.info(f"🚀 Starting HTTP server on port {args.port}")
-        logger.info(f"🔗 MCP endpoint: http://localhost:{args.port}/mcp")
-        app.run(transport="sse", port=args.port, host="0.0.0.0")
+        logger.info(f"🔗 SSE endpoint: http://localhost:{args.port}/sse")
+        logger.info(f"🔗 Messages endpoint: http://localhost:{args.port}/messages/")
+        app.run(transport="sse", port=args.port, host="0.0.0.0", path="/mcp")
     else:
         logger.info("🚀 Starting stdio server (for uvx/Claude Desktop)")
         app.run(transport="stdio")
