@@ -5,8 +5,8 @@ A system for ingesting, synthesizing, and retrieving personal cognition
 from chat exports using dual vector+graph storage.
 """
 
-__version__ = "0.1.0"
-__author__ = "GenovoAI"
+__version__ = "0.1.2"
+__author__ = "Yasin Salimibeni"
 
 __all__ = []
 
