@@ -6,7 +6,7 @@ Load, normalize, chunk, and annotate chat exports into memory-sized units.
 
 from rebrain.ingestion.loaders import ChatLoader, ChatGPTJSONLoader
 from rebrain.ingestion.chunkers import MemoryChunker
-from rebrain.ingestion.annotators import MemoryAnnotator
+from rebrain.ingestion.parsers import parse_chatgpt_conversation
 from rebrain.ingestion.models import (
     Conversation,
     ConversationExport,
@@ -21,7 +21,7 @@ __all__ = [
     "ChatLoader",
     "ChatGPTJSONLoader",
     "MemoryChunker",
-    "MemoryAnnotator",
+    "parse_chatgpt_conversation",
     "Conversation",
     "ConversationExport",
     "ConversationMetadata",
